package
Version:
v0.1.94
Opens a new window with list of versions in this module.
Published: Nov 2, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func DiskTest(language, testMethod, testPath string, isMultiCheck bool, autoChange bool) (realTestMethod, res string)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.