Documentation
¶
Index ¶
- func AppendAnalysisSummary(config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
- func AppendTimeInfo(config *params.Config, output, tempOutput string, startTime time.Time, ...) string
- func HandleSignalInterrupt(ctx context.Context, cancel context.CancelFunc, sig chan os.Signal, ...)
- func HandleUploadResults(config *params.Config, output string)
- func RunBasicTests(ctx context.Context, preCheck utils.NetCheckResult, config *params.Config, ...) string
- func RunCPUTest(ctx context.Context, config *params.Config, output, tempOutput string, ...) string
- func RunChineseTests(ctx context.Context, preCheck utils.NetCheckResult, config *params.Config, ...)
- func RunDiskTest(ctx context.Context, config *params.Config, output, tempOutput string, ...) string
- func RunEmailTests(ctx context.Context, config *params.Config, wg2 *sync.WaitGroup, ...) string
- func RunEnglishNetworkTests(ctx context.Context, config *params.Config, wg3 *sync.WaitGroup, ...) string
- func RunEnglishSpeedTests(ctx context.Context, config *params.Config, output, tempOutput string, ...) string
- func RunEnglishTests(ctx context.Context, preCheck utils.NetCheckResult, config *params.Config, ...)
- func RunIpInfoCheck(ctx context.Context, config *params.Config, output, tempOutput string, ...) string
- func RunMemoryTest(ctx context.Context, config *params.Config, output, tempOutput string, ...) string
- func RunNetworkTests(ctx context.Context, config *params.Config, wg3 *sync.WaitGroup, ...) string
- func RunSecurityTests(ctx context.Context, config *params.Config, ...) string
- func RunSpeedTests(ctx context.Context, config *params.Config, output, tempOutput string, ...) string
- func RunStreamingTests(ctx context.Context, config *params.Config, wg1 *sync.WaitGroup, ...) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppendAnalysisSummary ¶ added in v0.1.119
func AppendAnalysisSummary(config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
AppendAnalysisSummary appends a concise bilingual summary for easier interpretation.
func AppendTimeInfo ¶
func AppendTimeInfo(config *params.Config, output, tempOutput string, startTime time.Time, outputMutex *sync.Mutex) string
AppendTimeInfo appends timing information
func HandleSignalInterrupt ¶
func HandleSignalInterrupt(ctx context.Context, cancel context.CancelFunc, sig chan os.Signal, config *params.Config, startTime *time.Time, output *string, tempOutput string, uploadDone chan bool, outputMutex *sync.Mutex)
HandleSignalInterrupt handles interrupt signals
First Ctrl+C → cancel the context (no new tests start) and wait for the currently-running test to finish, then upload & exit gracefully.
Second Ctrl+C (or if cleanup takes > 30 s) → kill the process group so that any child subprocess (stream, fio, dd, sysbench, geekbench …) is also terminated immediately, then os.Exit(1).
func HandleUploadResults ¶
HandleUploadResults handles uploading results
func RunBasicTests ¶
func RunBasicTests(ctx context.Context, preCheck utils.NetCheckResult, config *params.Config, basicInfo, securityInfo *string, output, tempOutput string, outputMutex *sync.Mutex) string
RunBasicTests runs basic system tests
func RunCPUTest ¶
func RunCPUTest(ctx context.Context, config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
RunCPUTest runs CPU test
func RunChineseTests ¶
func RunChineseTests(ctx context.Context, preCheck utils.NetCheckResult, config *params.Config, wg1, wg2, wg3 *sync.WaitGroup, basicInfo, securityInfo, emailInfo, mediaInfo, ptInfo *string, output *string, tempOutput string, startTime time.Time, outputMutex *sync.Mutex, infoMutex *sync.Mutex)
RunChineseTests runs all tests in Chinese mode
func RunDiskTest ¶
func RunDiskTest(ctx context.Context, config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
RunDiskTest runs disk test
func RunEmailTests ¶
func RunEmailTests(ctx context.Context, config *params.Config, wg2 *sync.WaitGroup, emailInfo *string, output, tempOutput string, outputMutex *sync.Mutex, infoMutex *sync.Mutex) string
RunEmailTests runs email port tests
func RunEnglishNetworkTests ¶
func RunEnglishNetworkTests(ctx context.Context, config *params.Config, wg3 *sync.WaitGroup, ptInfo *string, output, tempOutput string, outputMutex *sync.Mutex) string
RunEnglishNetworkTests runs network tests (English mode)
func RunEnglishSpeedTests ¶
func RunEnglishSpeedTests(ctx context.Context, config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
RunEnglishSpeedTests runs speed tests (English mode)
func RunEnglishTests ¶
func RunEnglishTests(ctx context.Context, preCheck utils.NetCheckResult, config *params.Config, wg1, wg2, wg3 *sync.WaitGroup, basicInfo, securityInfo, emailInfo, mediaInfo, ptInfo *string, output *string, tempOutput string, startTime time.Time, outputMutex *sync.Mutex, infoMutex *sync.Mutex)
RunEnglishTests runs all tests in English mode
func RunIpInfoCheck ¶
func RunIpInfoCheck(ctx context.Context, config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
RunIpInfoCheck performs IP info check
func RunMemoryTest ¶
func RunMemoryTest(ctx context.Context, config *params.Config, output, tempOutput string, outputMutex *sync.Mutex) string
RunMemoryTest runs memory test
func RunNetworkTests ¶
func RunNetworkTests(ctx context.Context, config *params.Config, wg3 *sync.WaitGroup, ptInfo *string, output, tempOutput string, outputMutex *sync.Mutex, infoMutex *sync.Mutex) string
RunNetworkTests runs network tests (Chinese mode)
func RunSecurityTests ¶
func RunSecurityTests(ctx context.Context, config *params.Config, securityInfo, output, tempOutput string, outputMutex *sync.Mutex) string
RunSecurityTests runs security tests
Types ¶
This section is empty.